searchData={"items":[{"type":"module","title":"Livekitex","doc":"LiveKit Elixir SDK - A comprehensive client library for LiveKit.\n\nLiveKit is an open-source WebRTC infrastructure for building real-time\nvideo and audio applications. This SDK provides a complete set of tools\nfor integrating with LiveKit servers, including:\n\n- Room management and participant control\n- Access token generation and validation\n- Webhook processing and validation\n- Structured logging and telemetry","ref":"Livekitex.html"},{"type":"module","title":"Quick Start - Livekitex","doc":"# Configure the SDK\n    config :livekitex,\n      api_key: \"your_api_key\",\n      api_secret: \"your_api_secret\",\n      host: \"your_livekit_host\"\n\n    # Create a room service client\n    client = Livekitex.room_service()\n\n    # Create a room\n    {:ok, room} = Livekitex.RoomService.create_room(client, \"my-room\")\n\n    # Generate an access token\n    token = Livekitex.access_token(\"participant_identity\")\n    |> Livekitex.AccessToken.add_grant(%Livekitex.Grants.VideoGrant{\n      room_join: true,\n      room: \"my-room\"\n    })\n    |> Livekitex.AccessToken.to_jwt()","ref":"Livekitex.html#module-quick-start"},{"type":"module","title":"Configuration - Livekitex","doc":"The SDK can be configured through multiple sources:\n\n1. Application configuration (config.exs)\n2. Environment variables\n3. Runtime configuration\n\nSee `Livekitex.Config` for detailed configuration options.","ref":"Livekitex.html#module-configuration"},{"type":"module","title":"Services - Livekitex","doc":"- `Livekitex.RoomService` - Room and participant management\n- `Livekitex.Webhook` - Webhook validation and processing\n- `Livekitex.AccessToken` - Token generation and validation","ref":"Livekitex.html#module-services"},{"type":"function","title":"Livekitex.access_token/2","doc":"Creates an access token for the given identity.","ref":"Livekitex.html#access_token/2"},{"type":"function","title":"Parameters - Livekitex.access_token/2","doc":"- `identity` - Participant identity\n- `opts` - Token options (optional)","ref":"Livekitex.html#access_token/2-parameters"},{"type":"function","title":"Options - Livekitex.access_token/2","doc":"- `:ttl` - Token time-to-live in seconds (default: 600)\n- `:name` - Participant name\n- `:metadata` - Additional metadata\n- `:attributes` - Additional attributes","ref":"Livekitex.html#access_token/2-options"},{"type":"function","title":"Examples - Livekitex.access_token/2","doc":"token = Livekitex.access_token(\"user123\")\n    |> Livekitex.AccessToken.set_video_grant(%Livekitex.Grants.VideoGrant{\n      room_join: true,\n      room: \"my-room\"\n    })\n    |> Livekitex.AccessToken.to_jwt()","ref":"Livekitex.html#access_token/2-examples"},{"type":"function","title":"Livekitex.admin_token/1","doc":"Creates an admin token with full permissions.\n\nThis token can be used for administrative operations like\ncreating rooms, managing participants, etc.","ref":"Livekitex.html#admin_token/1"},{"type":"function","title":"Parameters - Livekitex.admin_token/1","doc":"- `opts` - Token options (optional)","ref":"Livekitex.html#admin_token/1-parameters"},{"type":"function","title":"Options - Livekitex.admin_token/1","doc":"- `:ttl` - Token time-to-live in seconds (default: 3600)\n- `:room` - Specific room (optional, for room-specific admin)","ref":"Livekitex.html#admin_token/1-options"},{"type":"function","title":"Examples - Livekitex.admin_token/1","doc":"{:ok, token} = Livekitex.admin_token()\n\n    {:ok, token} = Livekitex.admin_token(room: \"my-room\", ttl: 7200)","ref":"Livekitex.html#admin_token/1-examples"},{"type":"function","title":"Livekitex.config/0","doc":"Gets the current configuration.","ref":"Livekitex.html#config/0"},{"type":"function","title":"Examples - Livekitex.config/0","doc":"config = Livekitex.config()\n    # %{host: \"localhost:7880\", api_key: \"...\", ...}","ref":"Livekitex.html#config/0-examples"},{"type":"function","title":"Livekitex.configure/2","doc":"Updates configuration at runtime.","ref":"Livekitex.html#configure/2"},{"type":"function","title":"Parameters - Livekitex.configure/2","doc":"- `key` - Configuration key\n- `value` - Configuration value","ref":"Livekitex.html#configure/2-parameters"},{"type":"function","title":"Examples - Livekitex.configure/2","doc":"Livekitex.configure(:host, \"production.livekit.io:443\")\n    Livekitex.configure(:use_tls, true)","ref":"Livekitex.html#configure/2-examples"},{"type":"function","title":"Livekitex.room_join_token/3","doc":"Creates a room join token for the given identity and room.\n\nThis is a convenience function that creates an access token with\nroom join permissions.","ref":"Livekitex.html#room_join_token/3"},{"type":"function","title":"Parameters - Livekitex.room_join_token/3","doc":"- `identity` - Participant identity\n- `room` - Room name\n- `opts` - Additional options","ref":"Livekitex.html#room_join_token/3-parameters"},{"type":"function","title":"Options - Livekitex.room_join_token/3","doc":"- `:ttl` - Token time-to-live in seconds (default: 3600)\n- `:can_publish` - Can publish tracks (default: true)\n- `:can_subscribe` - Can subscribe to tracks (default: true)\n- `:can_publish_data` - Can publish data (default: true)\n- `:hidden` - Hidden participant (default: false)\n- `:recorder` - Recorder participant (default: false)\n- `:metadata` - Participant metadata","ref":"Livekitex.html#room_join_token/3-options"},{"type":"function","title":"Examples - Livekitex.room_join_token/3","doc":"{:ok, token} = Livekitex.room_join_token(\"user123\", \"my-room\")\n\n    {:ok, token} = Livekitex.room_join_token(\"user123\", \"my-room\",\n      can_publish: false,\n      metadata: %{\"role\" => \"viewer\"}\n    )","ref":"Livekitex.html#room_join_token/3-examples"},{"type":"function","title":"Livekitex.room_service/0","doc":"Creates a room service client with current configuration.","ref":"Livekitex.html#room_service/0"},{"type":"function","title":"Examples - Livekitex.room_service/0","doc":"client = Livekitex.room_service()\n    {:ok, room} = Livekitex.RoomService.create_room(client, \"my-room\")","ref":"Livekitex.html#room_service/0-examples"},{"type":"function","title":"Livekitex.start/0","doc":"Starts the LiveKit SDK application.\n\nThis sets up telemetry and other infrastructure.","ref":"Livekitex.html#start/0"},{"type":"function","title":"Examples - Livekitex.start/0","doc":"Livekitex.start()","ref":"Livekitex.html#start/0-examples"},{"type":"function","title":"Livekitex.stop/0","doc":"Stops the LiveKit SDK application.","ref":"Livekitex.html#stop/0"},{"type":"function","title":"Examples - Livekitex.stop/0","doc":"Livekitex.stop()","ref":"Livekitex.html#stop/0-examples"},{"type":"function","title":"Livekitex.validate_webhook/3","doc":"Validates a webhook request.","ref":"Livekitex.html#validate_webhook/3"},{"type":"function","title":"Parameters - Livekitex.validate_webhook/3","doc":"- `body` - Raw webhook body\n- `auth_header` - Authorization header\n- `api_secret` - API secret (optional, uses configured secret if not provided)","ref":"Livekitex.html#validate_webhook/3-parameters"},{"type":"function","title":"Examples - Livekitex.validate_webhook/3","doc":"{:ok, event} = Livekitex.validate_webhook(body, auth_header)\n\n    {:ok, event} = Livekitex.validate_webhook(body, auth_header, \"custom_secret\")","ref":"Livekitex.html#validate_webhook/3-examples"},{"type":"function","title":"Livekitex.version/0","doc":"Gets the current SDK version.","ref":"Livekitex.html#version/0"},{"type":"function","title":"Examples - Livekitex.version/0","doc":"iex> Livekitex.version()\n    \"0.1.0\"","ref":"Livekitex.html#version/0-examples"},{"type":"module","title":"Livekitex.AccessToken","doc":"Provides functionality to create and manage LiveKit access tokens.","ref":"Livekitex.AccessToken.html"},{"type":"function","title":"Livekitex.AccessToken.create/3","doc":"Creates a new AccessToken.","ref":"Livekitex.AccessToken.html#create/3"},{"type":"function","title":"Parameters - Livekitex.AccessToken.create/3","doc":"- `api_key`: The API key for your LiveKit project.\n  - `api_secret`: The API secret for your LiveKit project.\n  - `options`: A keyword list of options.\n    - `identity`: The identity of the user.\n    - `name`: The name of the user.\n    - `ttl`: The time-to-live for the token in seconds. Defaults to 600 (10 minutes).\n    - `metadata`: A string of metadata to associate with the user.\n    - `attributes`: A map of attributes to associate with the user.","ref":"Livekitex.AccessToken.html#create/3-parameters"},{"type":"function","title":"Examples - Livekitex.AccessToken.create/3","doc":"iex> Livekitex.AccessToken.create(\"api_key\", \"api_secret\", identity: \"user\", name: \"User Name\")\n    %Livekitex.AccessToken{\n      api_key: \"api_key\",\n      api_secret: \"api_secret\",\n      identity: \"user\",\n      ttl: 600,\n      grants: %Livekitex.Grants.ClaimGrant{name: \"User Name\"}\n    }","ref":"Livekitex.AccessToken.html#create/3-examples"},{"type":"function","title":"Livekitex.AccessToken.set_attributes/2","doc":"Sets attributes for the access token.","ref":"Livekitex.AccessToken.html#set_attributes/2"},{"type":"function","title":"Parameters - Livekitex.AccessToken.set_attributes/2","doc":"- `access_token`: The AccessToken struct.\n  - `attributes`: A map of attributes to associate with the user.","ref":"Livekitex.AccessToken.html#set_attributes/2-parameters"},{"type":"function","title":"Livekitex.AccessToken.set_metadata/2","doc":"Sets metadata for the access token.","ref":"Livekitex.AccessToken.html#set_metadata/2"},{"type":"function","title":"Parameters - Livekitex.AccessToken.set_metadata/2","doc":"- `access_token`: The AccessToken struct.\n  - `metadata`: A string of metadata to associate with the user.","ref":"Livekitex.AccessToken.html#set_metadata/2-parameters"},{"type":"function","title":"Livekitex.AccessToken.set_name/2","doc":"Sets the name for the access token.","ref":"Livekitex.AccessToken.html#set_name/2"},{"type":"function","title":"Parameters - Livekitex.AccessToken.set_name/2","doc":"- `access_token`: The AccessToken struct.\n  - `name`: The name of the user.","ref":"Livekitex.AccessToken.html#set_name/2-parameters"},{"type":"function","title":"Livekitex.AccessToken.set_room_config/2","doc":"Sets room configuration for the access token.","ref":"Livekitex.AccessToken.html#set_room_config/2"},{"type":"function","title":"Parameters - Livekitex.AccessToken.set_room_config/2","doc":"- `access_token`: The AccessToken struct.\n  - `room_config`: A map representing room configuration.","ref":"Livekitex.AccessToken.html#set_room_config/2-parameters"},{"type":"function","title":"Livekitex.AccessToken.set_room_preset/2","doc":"Sets room preset for the access token.","ref":"Livekitex.AccessToken.html#set_room_preset/2"},{"type":"function","title":"Parameters - Livekitex.AccessToken.set_room_preset/2","doc":"- `access_token`: The AccessToken struct.\n  - `room_preset`: A string representing the room preset.","ref":"Livekitex.AccessToken.html#set_room_preset/2-parameters"},{"type":"function","title":"Livekitex.AccessToken.set_sha256/2","doc":"Sets the SHA256 hash for the access token.","ref":"Livekitex.AccessToken.html#set_sha256/2"},{"type":"function","title":"Parameters - Livekitex.AccessToken.set_sha256/2","doc":"- `access_token`: The AccessToken struct.\n  - `sha256`: The SHA256 hash string.","ref":"Livekitex.AccessToken.html#set_sha256/2-parameters"},{"type":"function","title":"Livekitex.AccessToken.set_sip_grant/2","doc":"Sets the SIP grant for the access token.","ref":"Livekitex.AccessToken.html#set_sip_grant/2"},{"type":"function","title":"Parameters - Livekitex.AccessToken.set_sip_grant/2","doc":"- `access_token`: The AccessToken struct.\n  - `sip_grant`: A SipGrant struct or keyword list of SIP permissions.","ref":"Livekitex.AccessToken.html#set_sip_grant/2-parameters"},{"type":"function","title":"Examples - Livekitex.AccessToken.set_sip_grant/2","doc":"iex> token = Livekitex.AccessToken.create(\"api_key\", \"api_secret\", identity: \"user\")\n    iex> sip_grant = Livekitex.Grants.SipGrant.new(admin: true)\n    iex> token = Livekitex.AccessToken.set_sip_grant(token, sip_grant)","ref":"Livekitex.AccessToken.html#set_sip_grant/2-examples"},{"type":"function","title":"Livekitex.AccessToken.set_video_grant/2","doc":"Sets the video grant for the access token.","ref":"Livekitex.AccessToken.html#set_video_grant/2"},{"type":"function","title":"Parameters - Livekitex.AccessToken.set_video_grant/2","doc":"- `access_token`: The AccessToken struct.\n  - `video_grant`: A VideoGrant struct or keyword list of video permissions.","ref":"Livekitex.AccessToken.html#set_video_grant/2-parameters"},{"type":"function","title":"Examples - Livekitex.AccessToken.set_video_grant/2","doc":"iex> token = Livekitex.AccessToken.create(\"api_key\", \"api_secret\", identity: \"user\")\n    iex> video_grant = Livekitex.Grants.VideoGrant.new(room_join: true, can_publish: true)\n    iex> token = Livekitex.AccessToken.set_video_grant(token, video_grant)","ref":"Livekitex.AccessToken.html#set_video_grant/2-examples"},{"type":"type","title":"Livekitex.AccessToken.t/0","doc":"","ref":"Livekitex.AccessToken.html#t:t/0"},{"type":"function","title":"Livekitex.AccessToken.to_jwt/1","doc":"Generates a JWT token from an AccessToken.","ref":"Livekitex.AccessToken.html#to_jwt/1"},{"type":"function","title":"Examples - Livekitex.AccessToken.to_jwt/1","doc":"iex> token = Livekitex.AccessToken.create(\"devkey\", \"secret\", identity: \"user\", name: \"User Name\")\n    iex> video_grant = Livekitex.Grants.VideoGrant.new(room_join: true)\n    iex> token = Livekitex.AccessToken.set_video_grant(token, video_grant)\n    iex> {:ok, jwt, _claims} = Livekitex.AccessToken.to_jwt(token)\n    iex> is_binary(jwt)\n    true","ref":"Livekitex.AccessToken.html#to_jwt/1-examples"},{"type":"function","title":"Livekitex.AccessToken.to_jwt!/1","doc":"Generates a JWT token from an AccessToken, raising on error.","ref":"Livekitex.AccessToken.html#to_jwt!/1"},{"type":"function","title":"Examples - Livekitex.AccessToken.to_jwt!/1","doc":"iex> token = Livekitex.AccessToken.create(\"devkey\", \"secret\", identity: \"user\")\n    iex> video_grant = Livekitex.Grants.VideoGrant.new(room_join: true)\n    iex> token = Livekitex.AccessToken.set_video_grant(token, video_grant)\n    iex> jwt = Livekitex.AccessToken.to_jwt!(token)\n    iex> is_binary(jwt)\n    true","ref":"Livekitex.AccessToken.html#to_jwt!/1-examples"},{"type":"module","title":"Livekitex.Application","doc":"Application module for Livekitex.","ref":"Livekitex.Application.html"},{"type":"function","title":"Livekitex.Application.start/2","doc":"Callback implementation for  Application.start/2 .","ref":"Livekitex.Application.html#start/2"},{"type":"module","title":"Livekitex.Config","doc":"Configuration management for LiveKit Elixir SDK.\n\nThis module provides centralized configuration management with support for\ndifferent environments (dev, test, prod) and runtime configuration.","ref":"Livekitex.Config.html"},{"type":"function","title":"Livekitex.Config.client_config/0","doc":"Creates a client configuration map from the current config.\n\nThis is useful for creating service clients with the current configuration.","ref":"Livekitex.Config.html#client_config/0"},{"type":"function","title":"Examples - Livekitex.Config.client_config/0","doc":"iex> Livekitex.Config.client_config()\n    %{\n      api_key: \"your_api_key\",\n      api_secret: \"your_api_secret\",\n      host: \"localhost:7880\"\n    }","ref":"Livekitex.Config.html#client_config/0-examples"},{"type":"function","title":"Livekitex.Config.get/0","doc":"Gets the current configuration for the LiveKit SDK.\n\nConfiguration is loaded from multiple sources in order of precedence:\n1. Runtime configuration (highest priority)\n2. Application environment\n3. System environment variables\n4. Default values (lowest priority)","ref":"Livekitex.Config.html#get/0"},{"type":"function","title":"Examples - Livekitex.Config.get/0","doc":"iex> Livekitex.Config.get()\n    %{\n      host: \"localhost:7880\",\n      use_tls: false,\n      api_key: \"your_api_key\",\n      api_secret: \"your_api_secret\",\n      timeout: 30000,\n      ...\n    }","ref":"Livekitex.Config.html#get/0-examples"},{"type":"function","title":"Livekitex.Config.get/2","doc":"Gets a specific configuration value.","ref":"Livekitex.Config.html#get/2"},{"type":"function","title":"Parameters - Livekitex.Config.get/2","doc":"- `key` - Configuration key (atom)\n- `default` - Default value if key is not found","ref":"Livekitex.Config.html#get/2-parameters"},{"type":"function","title":"Examples - Livekitex.Config.get/2","doc":"iex> Livekitex.Config.get(:host)\n    \"localhost:7880\"\n\n    iex> Livekitex.Config.get(:custom_key, \"default_value\")\n    \"default_value\"","ref":"Livekitex.Config.html#get/2-examples"},{"type":"function","title":"Livekitex.Config.get_env_config/1","doc":"Gets the configuration for a specific environment.","ref":"Livekitex.Config.html#get_env_config/1"},{"type":"function","title":"Parameters - Livekitex.Config.get_env_config/1","doc":"- `env` - Environment atom (:dev, :test, :prod)","ref":"Livekitex.Config.html#get_env_config/1-parameters"},{"type":"function","title":"Examples - Livekitex.Config.get_env_config/1","doc":"iex> Livekitex.Config.get_env_config(:prod)\n    %{host: \"livekit.example.com:443\", use_tls: true, ...}","ref":"Livekitex.Config.html#get_env_config/1-examples"},{"type":"function","title":"Livekitex.Config.grpc_options/0","doc":"Gets gRPC connection options from the current configuration.","ref":"Livekitex.Config.html#grpc_options/0"},{"type":"function","title":"Examples - Livekitex.Config.grpc_options/0","doc":"iex> Livekitex.Config.grpc_options()\n    [\n      timeout: 30000,\n      max_retries: 3,\n      retry_delay: 1000,\n      pool_size: 10,\n      pool_max_overflow: 5\n    ]","ref":"Livekitex.Config.html#grpc_options/0-examples"},{"type":"function","title":"Livekitex.Config.put/2","doc":"Sets a runtime configuration value.\n\nThis allows for dynamic configuration changes at runtime.\nRuntime configuration has the highest precedence.","ref":"Livekitex.Config.html#put/2"},{"type":"function","title":"Parameters - Livekitex.Config.put/2","doc":"- `key` - Configuration key (atom)\n- `value` - Configuration value","ref":"Livekitex.Config.html#put/2-parameters"},{"type":"function","title":"Examples - Livekitex.Config.put/2","doc":"iex> Livekitex.Config.put(:host, \"production.livekit.io:443\")\n    :ok\n\n    iex> Livekitex.Config.put(:use_tls, true)\n    :ok","ref":"Livekitex.Config.html#put/2-examples"},{"type":"function","title":"Livekitex.Config.reset/0","doc":"Resets runtime configuration to defaults.\n\nThis removes all runtime configuration overrides.","ref":"Livekitex.Config.html#reset/0"},{"type":"function","title":"Examples - Livekitex.Config.reset/0","doc":"iex> Livekitex.Config.reset()\n    :ok","ref":"Livekitex.Config.html#reset/0-examples"},{"type":"function","title":"Livekitex.Config.validate/0","doc":"Validates the current configuration.","ref":"Livekitex.Config.html#validate/0"},{"type":"function","title":"Returns - Livekitex.Config.validate/0","doc":"- `{:ok, config}` - Configuration is valid\n- `{:error, reason}` - Configuration is invalid","ref":"Livekitex.Config.html#validate/0-returns"},{"type":"function","title":"Examples - Livekitex.Config.validate/0","doc":"iex> Livekitex.Config.validate()\n    {:ok, %{host: \"localhost:7880\", ...}}\n\n    iex> Livekitex.Config.validate()\n    {:error, \"API key is required\"}","ref":"Livekitex.Config.html#validate/0-examples"},{"type":"module","title":"Livekitex.Grants","doc":"Provides grant structures for LiveKit access tokens.","ref":"Livekitex.Grants.html"},{"type":"module","title":"Livekitex.Grants.ClaimGrant","doc":"Complete claim grant structure containing all permissions and metadata.","ref":"Livekitex.Grants.ClaimGrant.html"},{"type":"function","title":"Livekitex.Grants.ClaimGrant.from_claims/1","doc":"Creates a ClaimGrant from a JWT claims map.","ref":"Livekitex.Grants.ClaimGrant.html#from_claims/1"},{"type":"type","title":"Livekitex.Grants.ClaimGrant.t/0","doc":"","ref":"Livekitex.Grants.ClaimGrant.html#t:t/0"},{"type":"function","title":"Livekitex.Grants.ClaimGrant.to_claims/1","doc":"Converts a ClaimGrant to a map for JWT encoding.","ref":"Livekitex.Grants.ClaimGrant.html#to_claims/1"},{"type":"module","title":"Livekitex.Grants.SipGrant","doc":"SIP-related permissions for LiveKit access tokens.","ref":"Livekitex.Grants.SipGrant.html"},{"type":"function","title":"Livekitex.Grants.SipGrant.from_map/1","doc":"Creates a SipGrant from a map/hash.","ref":"Livekitex.Grants.SipGrant.html#from_map/1"},{"type":"function","title":"Livekitex.Grants.SipGrant.new/1","doc":"Creates a new SipGrant with the specified permissions.","ref":"Livekitex.Grants.SipGrant.html#new/1"},{"type":"type","title":"Livekitex.Grants.SipGrant.t/0","doc":"","ref":"Livekitex.Grants.SipGrant.html#t:t/0"},{"type":"function","title":"Livekitex.Grants.SipGrant.to_map/1","doc":"Converts a SipGrant to a map for JWT encoding.","ref":"Livekitex.Grants.SipGrant.html#to_map/1"},{"type":"module","title":"Livekitex.Grants.VideoGrant","doc":"Video-related permissions for LiveKit access tokens.","ref":"Livekitex.Grants.VideoGrant.html"},{"type":"function","title":"Livekitex.Grants.VideoGrant.from_map/1","doc":"Creates a VideoGrant from a map/hash.","ref":"Livekitex.Grants.VideoGrant.html#from_map/1"},{"type":"function","title":"Livekitex.Grants.VideoGrant.new/1","doc":"Creates a new VideoGrant with the specified permissions.","ref":"Livekitex.Grants.VideoGrant.html#new/1"},{"type":"function","title":"Parameters - Livekitex.Grants.VideoGrant.new/1","doc":"- `opts`: A keyword list of video permissions.","ref":"Livekitex.Grants.VideoGrant.html#new/1-parameters"},{"type":"function","title":"Examples - Livekitex.Grants.VideoGrant.new/1","doc":"iex> Livekitex.Grants.VideoGrant.new(room_join: true, can_publish: true)\n    %Livekitex.Grants.VideoGrant{room_join: true, can_publish: true}","ref":"Livekitex.Grants.VideoGrant.html#new/1-examples"},{"type":"type","title":"Livekitex.Grants.VideoGrant.t/0","doc":"","ref":"Livekitex.Grants.VideoGrant.html#t:t/0"},{"type":"function","title":"Livekitex.Grants.VideoGrant.to_map/1","doc":"Converts a VideoGrant to a map for JWT encoding.","ref":"Livekitex.Grants.VideoGrant.html#to_map/1"},{"type":"module","title":"Livekitex.Logger","doc":"Structured logging system for LiveKit Elixir SDK.\n\nThis module provides structured logging with telemetry integration,\ncontext tracking, and performance monitoring for LiveKit operations.","ref":"Livekitex.Logger.html"},{"type":"function","title":"Livekitex.Logger.debug/2","doc":"Logs debug information.","ref":"Livekitex.Logger.html#debug/2"},{"type":"function","title":"Parameters - Livekitex.Logger.debug/2","doc":"- `message` - Debug message\n- `metadata` - Additional metadata (optional)","ref":"Livekitex.Logger.html#debug/2-parameters"},{"type":"function","title":"Livekitex.Logger.error/2","doc":"Logs error messages.","ref":"Livekitex.Logger.html#error/2"},{"type":"function","title":"Parameters - Livekitex.Logger.error/2","doc":"- `message` - Error message\n- `metadata` - Additional metadata (optional)","ref":"Livekitex.Logger.html#error/2-parameters"},{"type":"function","title":"Livekitex.Logger.info/2","doc":"Logs informational messages.","ref":"Livekitex.Logger.html#info/2"},{"type":"function","title":"Parameters - Livekitex.Logger.info/2","doc":"- `message` - Info message\n- `metadata` - Additional metadata (optional)","ref":"Livekitex.Logger.html#info/2-parameters"},{"type":"function","title":"Livekitex.Logger.log/3","doc":"Logs a structured message with context and telemetry.","ref":"Livekitex.Logger.html#log/3"},{"type":"function","title":"Parameters - Livekitex.Logger.log/3","doc":"- `level` - Log level (:debug, :info, :warning, :error)\n- `message` - Log message\n- `metadata` - Additional metadata (optional)","ref":"Livekitex.Logger.html#log/3-parameters"},{"type":"function","title":"Examples - Livekitex.Logger.log/3","doc":"iex> Livekitex.Logger.log(:info, \"Room created\", %{room_name: \"test-room\", participants: 2})\n\n    iex> Livekitex.Logger.log(:error, \"Connection failed\", %{host: \"localhost:7880\", error: \"timeout\"})","ref":"Livekitex.Logger.html#log/3-examples"},{"type":"function","title":"Livekitex.Logger.log_connection/3","doc":"Logs connection events (connect, disconnect, reconnect).","ref":"Livekitex.Logger.html#log_connection/3"},{"type":"function","title":"Parameters - Livekitex.Logger.log_connection/3","doc":"- `event` - Connection event (:connect, :disconnect, :reconnect)\n- `host` - Server host\n- `metadata` - Additional metadata (optional)","ref":"Livekitex.Logger.html#log_connection/3-parameters"},{"type":"function","title":"Livekitex.Logger.log_grpc_call/5","doc":"Logs gRPC request/response information.","ref":"Livekitex.Logger.html#log_grpc_call/5"},{"type":"function","title":"Parameters - Livekitex.Logger.log_grpc_call/5","doc":"- `service` - gRPC service name\n- `method` - gRPC method name\n- `request` - Request data (optional)\n- `response` - Response data (optional)\n- `metadata` - Additional metadata (optional)","ref":"Livekitex.Logger.html#log_grpc_call/5-parameters"},{"type":"function","title":"Livekitex.Logger.log_webhook/3","doc":"Logs webhook processing information.","ref":"Livekitex.Logger.html#log_webhook/3"},{"type":"function","title":"Parameters - Livekitex.Logger.log_webhook/3","doc":"- `event_type` - Webhook event type\n- `processing_result` - Result of processing (:ok, :error, etc.)\n- `metadata` - Additional metadata (optional)","ref":"Livekitex.Logger.html#log_webhook/3-parameters"},{"type":"function","title":"Livekitex.Logger.setup_telemetry/0","doc":"Sets up telemetry handlers for LiveKit events.\n\nThis should be called during application startup to register\ntelemetry event handlers.","ref":"Livekitex.Logger.html#setup_telemetry/0"},{"type":"function","title":"Examples - Livekitex.Logger.setup_telemetry/0","doc":"Livekitex.Logger.setup_telemetry()","ref":"Livekitex.Logger.html#setup_telemetry/0-examples"},{"type":"function","title":"Livekitex.Logger.start_operation/2","doc":"Logs the start of an operation and returns a timer function.","ref":"Livekitex.Logger.html#start_operation/2"},{"type":"function","title":"Parameters - Livekitex.Logger.start_operation/2","doc":"- `operation` - Operation name\n- `metadata` - Additional metadata (optional)","ref":"Livekitex.Logger.html#start_operation/2-parameters"},{"type":"function","title":"Returns - Livekitex.Logger.start_operation/2","doc":"A function that when called will log the operation completion with duration.","ref":"Livekitex.Logger.html#start_operation/2-returns"},{"type":"function","title":"Examples - Livekitex.Logger.start_operation/2","doc":"timer = Livekitex.Logger.start_operation(\"create_room\", %{room_name: \"test\"})\n    # ... perform operation ...\n    timer.() # Logs completion with duration","ref":"Livekitex.Logger.html#start_operation/2-examples"},{"type":"function","title":"Livekitex.Logger.teardown_telemetry/0","doc":"Removes telemetry handlers.","ref":"Livekitex.Logger.html#teardown_telemetry/0"},{"type":"function","title":"Examples - Livekitex.Logger.teardown_telemetry/0","doc":"Livekitex.Logger.teardown_telemetry()","ref":"Livekitex.Logger.html#teardown_telemetry/0-examples"},{"type":"function","title":"Livekitex.Logger.warning/2","doc":"Logs warning messages.","ref":"Livekitex.Logger.html#warning/2"},{"type":"function","title":"Parameters - Livekitex.Logger.warning/2","doc":"- `message` - Warning message\n- `metadata` - Additional metadata (optional)","ref":"Livekitex.Logger.html#warning/2-parameters"},{"type":"function","title":"Livekitex.Logger.with_operation/3","doc":"Logs an operation with automatic timing.","ref":"Livekitex.Logger.html#with_operation/3"},{"type":"function","title":"Parameters - Livekitex.Logger.with_operation/3","doc":"- `operation` - Operation name\n- `metadata` - Additional metadata (optional)\n- `fun` - Function to execute and time","ref":"Livekitex.Logger.html#with_operation/3-parameters"},{"type":"function","title":"Returns - Livekitex.Logger.with_operation/3","doc":"The result of the function execution.","ref":"Livekitex.Logger.html#with_operation/3-returns"},{"type":"function","title":"Examples - Livekitex.Logger.with_operation/3","doc":"result = Livekitex.Logger.with_operation(\"create_room\", %{room_name: \"test\"}, fn ->\n      # ... perform operation ...\n      {:ok, room}\n    end)","ref":"Livekitex.Logger.html#with_operation/3-examples"},{"type":"module","title":"Livekitex.Room","doc":"Represents a LiveKit room.","ref":"Livekitex.Room.html"},{"type":"type","title":"Livekitex.Room.t/0","doc":"","ref":"Livekitex.Room.html#t:t/0"},{"type":"module","title":"Livekitex.RoomService","doc":"Provides functionality to interact with the LiveKit RoomService API using Twirp.","ref":"Livekitex.RoomService.html"},{"type":"function","title":"Livekitex.RoomService.create/3","doc":"Creates a new RoomService client.","ref":"Livekitex.RoomService.html#create/3"},{"type":"function","title":"Parameters - Livekitex.RoomService.create/3","doc":"- `api_key`: The API key for your LiveKit project.\n  - `api_secret`: The API secret for your LiveKit project.\n  - `options`: A keyword list of options.\n    - `host`: The host of the LiveKit server. Defaults to \"localhost\".\n    - `port`: The port of the LiveKit server. Defaults to 7880.","ref":"Livekitex.RoomService.html#create/3-parameters"},{"type":"function","title":"Examples - Livekitex.RoomService.create/3","doc":"iex> Livekitex.RoomService.create(\"api_key\", \"api_secret\")\n    %Livekitex.RoomService{\n      api_key: \"api_key\",\n      api_secret: \"api_secret\",\n      host: \"localhost\",\n      port: 7880\n    }","ref":"Livekitex.RoomService.html#create/3-examples"},{"type":"function","title":"Livekitex.RoomService.create_room/3","doc":"Creates a new room.","ref":"Livekitex.RoomService.html#create_room/3"},{"type":"function","title":"Parameters - Livekitex.RoomService.create_room/3","doc":"- `room_service`: The RoomService client.\n  - `name`: The name of the room.\n  - `options`: A keyword list of options.\n    - `empty_timeout`: Room timeout when empty (seconds)\n    - `departure_timeout`: Timeout after participant departure (seconds)\n    - `max_participants`: Maximum number of participants\n    - `metadata`: Room metadata\n    - `min_playout_delay`: Minimum playout delay (ms)\n    - `max_playout_delay`: Maximum playout delay (ms)\n    - `sync_streams`: Whether to sync streams","ref":"Livekitex.RoomService.html#create_room/3-parameters"},{"type":"function","title":"Examples - Livekitex.RoomService.create_room/3","doc":"iex> room_service = Livekitex.RoomService.create(\"devkey\", \"secret\")\n    iex> Livekitex.RoomService.create_room(room_service, \"test-room\")\n    {:ok, %Livekitex.Room{}}","ref":"Livekitex.RoomService.html#create_room/3-examples"},{"type":"function","title":"Livekitex.RoomService.delete_room/2","doc":"Deletes a room.","ref":"Livekitex.RoomService.html#delete_room/2"},{"type":"function","title":"Parameters - Livekitex.RoomService.delete_room/2","doc":"- `room_service`: The RoomService client.\n  - `room_name`: The name of the room to delete.","ref":"Livekitex.RoomService.html#delete_room/2-parameters"},{"type":"function","title":"Examples - Livekitex.RoomService.delete_room/2","doc":"iex> room_service = Livekitex.RoomService.create(\"devkey\", \"secret\")\n    iex> Livekitex.RoomService.delete_room(room_service, \"test-room\")\n    :ok","ref":"Livekitex.RoomService.html#delete_room/2-examples"},{"type":"function","title":"Livekitex.RoomService.list_participants/2","doc":"Lists participants in a room.","ref":"Livekitex.RoomService.html#list_participants/2"},{"type":"function","title":"Parameters - Livekitex.RoomService.list_participants/2","doc":"- `room_service`: The RoomService client.\n  - `room_name`: The name of the room.","ref":"Livekitex.RoomService.html#list_participants/2-parameters"},{"type":"function","title":"Examples - Livekitex.RoomService.list_participants/2","doc":"iex> room_service = Livekitex.RoomService.create(\"devkey\", \"secret\")\n    iex> Livekitex.RoomService.list_participants(room_service, \"test-room\")\n    {:ok, []}","ref":"Livekitex.RoomService.html#list_participants/2-examples"},{"type":"function","title":"Livekitex.RoomService.list_rooms/2","doc":"Lists all rooms.","ref":"Livekitex.RoomService.html#list_rooms/2"},{"type":"function","title":"Parameters - Livekitex.RoomService.list_rooms/2","doc":"- `room_service`: The RoomService client.\n  - `options`: A keyword list of options.\n    - `names`: List of specific room names to filter by","ref":"Livekitex.RoomService.html#list_rooms/2-parameters"},{"type":"function","title":"Examples - Livekitex.RoomService.list_rooms/2","doc":"iex> room_service = Livekitex.RoomService.create(\"devkey\", \"secret\")\n    iex> Livekitex.RoomService.list_rooms(room_service)\n    {:ok, []}","ref":"Livekitex.RoomService.html#list_rooms/2-examples"},{"type":"function","title":"Livekitex.RoomService.mute_published_track/5","doc":"Mutes or unmutes a published track.","ref":"Livekitex.RoomService.html#mute_published_track/5"},{"type":"function","title":"Parameters - Livekitex.RoomService.mute_published_track/5","doc":"- `room_service`: The RoomService client.\n  - `room_name`: The name of the room.\n  - `identity`: The identity of the participant.\n  - `track_sid`: The SID of the track to mute/unmute.\n  - `muted`: Whether to mute (true) or unmute (false) the track.","ref":"Livekitex.RoomService.html#mute_published_track/5-parameters"},{"type":"function","title":"Examples - Livekitex.RoomService.mute_published_track/5","doc":"iex> room_service = Livekitex.RoomService.create(\"devkey\", \"secret\")\n    iex> Livekitex.RoomService.mute_published_track(room_service, \"test-room\", \"user123\", \"track_sid\", true)\n    {:ok, %{}}","ref":"Livekitex.RoomService.html#mute_published_track/5-examples"},{"type":"function","title":"Livekitex.RoomService.remove_participant/3","doc":"Removes a participant from a room.","ref":"Livekitex.RoomService.html#remove_participant/3"},{"type":"function","title":"Parameters - Livekitex.RoomService.remove_participant/3","doc":"- `room_service`: The RoomService client.\n  - `room_name`: The name of the room.\n  - `identity`: The identity of the participant to remove.","ref":"Livekitex.RoomService.html#remove_participant/3-parameters"},{"type":"function","title":"Examples - Livekitex.RoomService.remove_participant/3","doc":"iex> room_service = Livekitex.RoomService.create(\"devkey\", \"secret\")\n    iex> Livekitex.RoomService.remove_participant(room_service, \"test-room\", \"user123\")\n    :ok","ref":"Livekitex.RoomService.html#remove_participant/3-examples"},{"type":"type","title":"Livekitex.RoomService.t/0","doc":"","ref":"Livekitex.RoomService.html#t:t/0"},{"type":"behaviour","title":"Livekitex.RoomServiceBehaviour","doc":"Behaviour for Livekitex.RoomService.","ref":"Livekitex.RoomServiceBehaviour.html"},{"type":"callback","title":"Livekitex.RoomServiceBehaviour.create/3","doc":"","ref":"Livekitex.RoomServiceBehaviour.html#c:create/3"},{"type":"callback","title":"Livekitex.RoomServiceBehaviour.create_room/3","doc":"","ref":"Livekitex.RoomServiceBehaviour.html#c:create_room/3"},{"type":"callback","title":"Livekitex.RoomServiceBehaviour.delete_room/2","doc":"","ref":"Livekitex.RoomServiceBehaviour.html#c:delete_room/2"},{"type":"callback","title":"Livekitex.RoomServiceBehaviour.list_participants/2","doc":"","ref":"Livekitex.RoomServiceBehaviour.html#c:list_participants/2"},{"type":"callback","title":"Livekitex.RoomServiceBehaviour.list_rooms/2","doc":"","ref":"Livekitex.RoomServiceBehaviour.html#c:list_rooms/2"},{"type":"callback","title":"Livekitex.RoomServiceBehaviour.mute_published_track/5","doc":"","ref":"Livekitex.RoomServiceBehaviour.html#c:mute_published_track/5"},{"type":"callback","title":"Livekitex.RoomServiceBehaviour.remove_participant/3","doc":"","ref":"Livekitex.RoomServiceBehaviour.html#c:remove_participant/3"},{"type":"module","title":"Livekitex.RoomServiceClient","doc":"Twirp client for LiveKit RoomService operations.","ref":"Livekitex.RoomServiceClient.html"},{"type":"function","title":"Livekitex.RoomServiceClient.create_room/3","doc":"","ref":"Livekitex.RoomServiceClient.html#create_room/3"},{"type":"function","title":"Livekitex.RoomServiceClient.delete_room/3","doc":"","ref":"Livekitex.RoomServiceClient.html#delete_room/3"},{"type":"function","title":"Livekitex.RoomServiceClient.list_participants/3","doc":"","ref":"Livekitex.RoomServiceClient.html#list_participants/3"},{"type":"function","title":"Livekitex.RoomServiceClient.list_rooms/3","doc":"","ref":"Livekitex.RoomServiceClient.html#list_rooms/3"},{"type":"function","title":"Livekitex.RoomServiceClient.mute_published_track/3","doc":"","ref":"Livekitex.RoomServiceClient.html#mute_published_track/3"},{"type":"function","title":"Livekitex.RoomServiceClient.remove_participant/3","doc":"","ref":"Livekitex.RoomServiceClient.html#remove_participant/3"},{"type":"module","title":"Livekitex.TokenVerifier","doc":"Provides functionality to verify and validate LiveKit access tokens.","ref":"Livekitex.TokenVerifier.html"},{"type":"function","title":"Livekitex.TokenVerifier.decode_claims/1","doc":"Validates token claims without signature verification.\nUseful for inspecting token contents.","ref":"Livekitex.TokenVerifier.html#decode_claims/1"},{"type":"function","title":"Parameters - Livekitex.TokenVerifier.decode_claims/1","doc":"- `token`: The JWT token string to decode.","ref":"Livekitex.TokenVerifier.html#decode_claims/1-parameters"},{"type":"function","title":"Returns - Livekitex.TokenVerifier.decode_claims/1","doc":"- `{:ok, claim_grant}` on successful decoding.\n  - `{:error, reason}` on decoding failure.","ref":"Livekitex.TokenVerifier.html#decode_claims/1-returns"},{"type":"function","title":"Examples - Livekitex.TokenVerifier.decode_claims/1","doc":"iex> {:ok, claims} = Livekitex.TokenVerifier.decode_claims(token)\n    iex> claims.identity\n    \"user\"","ref":"Livekitex.TokenVerifier.html#decode_claims/1-examples"},{"type":"function","title":"Livekitex.TokenVerifier.new/2","doc":"Creates a new TokenVerifier.","ref":"Livekitex.TokenVerifier.html#new/2"},{"type":"function","title":"Parameters - Livekitex.TokenVerifier.new/2","doc":"- `api_key`: The API key for your LiveKit project.\n  - `api_secret`: The API secret for your LiveKit project.","ref":"Livekitex.TokenVerifier.html#new/2-parameters"},{"type":"function","title":"Examples - Livekitex.TokenVerifier.new/2","doc":"iex> Livekitex.TokenVerifier.new(\"api_key\", \"api_secret\")\n    %Livekitex.TokenVerifier{api_key: \"api_key\", api_secret: \"api_secret\"}","ref":"Livekitex.TokenVerifier.html#new/2-examples"},{"type":"type","title":"Livekitex.TokenVerifier.t/0","doc":"","ref":"Livekitex.TokenVerifier.html#t:t/0"},{"type":"function","title":"Livekitex.TokenVerifier.verify/2","doc":"Verifies a JWT token and returns the claims.","ref":"Livekitex.TokenVerifier.html#verify/2"},{"type":"function","title":"Parameters - Livekitex.TokenVerifier.verify/2","doc":"- `verifier`: A TokenVerifier struct.\n  - `token`: The JWT token string to verify.","ref":"Livekitex.TokenVerifier.html#verify/2-parameters"},{"type":"function","title":"Returns - Livekitex.TokenVerifier.verify/2","doc":"- `{:ok, claim_grant}` on successful verification.\n  - `{:error, reason}` on verification failure.","ref":"Livekitex.TokenVerifier.html#verify/2-returns"},{"type":"function","title":"Examples - Livekitex.TokenVerifier.verify/2","doc":"iex> verifier = Livekitex.TokenVerifier.new(\"devkey\", \"secret\")\n    iex> {:ok, claims} = Livekitex.TokenVerifier.verify(verifier, valid_token)\n    iex> claims.identity\n    \"user\"","ref":"Livekitex.TokenVerifier.html#verify/2-examples"},{"type":"function","title":"Livekitex.TokenVerifier.verify!/2","doc":"Verifies a JWT token and returns the claims, raising on error.","ref":"Livekitex.TokenVerifier.html#verify!/2"},{"type":"function","title":"Parameters - Livekitex.TokenVerifier.verify!/2","doc":"- `verifier`: A TokenVerifier struct.\n  - `token`: The JWT token string to verify.","ref":"Livekitex.TokenVerifier.html#verify!/2-parameters"},{"type":"function","title":"Returns - Livekitex.TokenVerifier.verify!/2","doc":"- `claim_grant` on successful verification.\n  - Raises an exception on verification failure.","ref":"Livekitex.TokenVerifier.html#verify!/2-returns"},{"type":"function","title":"Examples - Livekitex.TokenVerifier.verify!/2","doc":"iex> verifier = Livekitex.TokenVerifier.new(\"devkey\", \"secret\")\n    iex> claims = Livekitex.TokenVerifier.verify!(verifier, valid_token)\n    iex> claims.identity\n    \"user\"","ref":"Livekitex.TokenVerifier.html#verify!/2-examples"},{"type":"function","title":"Livekitex.TokenVerifier.verify_permissions/3","doc":"Validates specific permissions in a token.","ref":"Livekitex.TokenVerifier.html#verify_permissions/3"},{"type":"function","title":"Parameters - Livekitex.TokenVerifier.verify_permissions/3","doc":"- `verifier`: A TokenVerifier struct.\n  - `token`: The JWT token string to verify.\n  - `permissions`: A keyword list of required permissions.","ref":"Livekitex.TokenVerifier.html#verify_permissions/3-parameters"},{"type":"function","title":"Returns - Livekitex.TokenVerifier.verify_permissions/3","doc":"- `{:ok, claim_grant}` if token is valid and has required permissions.\n  - `{:error, reason}` if verification fails or permissions are insufficient.","ref":"Livekitex.TokenVerifier.html#verify_permissions/3-returns"},{"type":"function","title":"Examples - Livekitex.TokenVerifier.verify_permissions/3","doc":"iex> verifier = Livekitex.TokenVerifier.new(\"devkey\", \"secret\")\n    iex> {:ok, claims} = Livekitex.TokenVerifier.verify_permissions(verifier, token, room_join: true)","ref":"Livekitex.TokenVerifier.html#verify_permissions/3-examples"},{"type":"module","title":"Livekitex.TwirpUtils","doc":"Utilities for handling Twirp communication and errors.","ref":"Livekitex.TwirpUtils.html"},{"type":"function","title":"Livekitex.TwirpUtils.create_client/3","doc":"Creates Tesla client configuration for Twirp requests.","ref":"Livekitex.TwirpUtils.html#create_client/3"},{"type":"function","title":"Livekitex.TwirpUtils.format_twirp_error/1","doc":"Formats Twirp errors into more user-friendly error tuples.","ref":"Livekitex.TwirpUtils.html#format_twirp_error/1"},{"type":"function","title":"Livekitex.TwirpUtils.handle_twirp_response/1","doc":"Handles Twirp responses and converts them to standard Elixir patterns.","ref":"Livekitex.TwirpUtils.html#handle_twirp_response/1"},{"type":"function","title":"Livekitex.TwirpUtils.proto_to_participant/1","doc":"Converts a protobuf ParticipantInfo to a map.","ref":"Livekitex.TwirpUtils.html#proto_to_participant/1"},{"type":"function","title":"Livekitex.TwirpUtils.proto_to_room/1","doc":"Converts a protobuf Room to our internal Room struct.","ref":"Livekitex.TwirpUtils.html#proto_to_room/1"},{"type":"function","title":"Livekitex.TwirpUtils.proto_to_track/1","doc":"Converts a protobuf TrackInfo to a map.","ref":"Livekitex.TwirpUtils.html#proto_to_track/1"},{"type":"module","title":"Livekitex.Webhook","doc":"Webhook validation and processing for LiveKit events.\n\nThis module provides functionality to validate and process webhooks sent by LiveKit server.\nIt includes signature validation using HMAC-SHA256 and event parsing.","ref":"Livekitex.Webhook.html"},{"type":"function","title":"Livekitex.Webhook.create_plug/2","doc":"Creates a Plug for webhook validation middleware.","ref":"Livekitex.Webhook.html#create_plug/2"},{"type":"function","title":"Parameters - Livekitex.Webhook.create_plug/2","doc":"- `api_secret` - The API secret for signature validation\n- `opts` - Additional options (optional)","ref":"Livekitex.Webhook.html#create_plug/2-parameters"},{"type":"function","title":"Returns - Livekitex.Webhook.create_plug/2","doc":"A Plug that validates webhooks and assigns the event to conn.assigns.webhook_event","ref":"Livekitex.Webhook.html#create_plug/2-returns"},{"type":"function","title":"Livekitex.Webhook.parse_webhook_event/1","doc":"Parses a webhook event from JSON body.","ref":"Livekitex.Webhook.html#parse_webhook_event/1"},{"type":"function","title":"Parameters - Livekitex.Webhook.parse_webhook_event/1","doc":"- `body` - JSON string containing the webhook event","ref":"Livekitex.Webhook.html#parse_webhook_event/1-parameters"},{"type":"function","title":"Returns - Livekitex.Webhook.parse_webhook_event/1","doc":"- `{:ok, event}` - Successfully parsed event\n- `{:error, reason}` - Parsing failed","ref":"Livekitex.Webhook.html#parse_webhook_event/1-returns"},{"type":"function","title":"Livekitex.Webhook.validate_webhook/3","doc":"Validates a webhook request and returns the parsed event.","ref":"Livekitex.Webhook.html#validate_webhook/3"},{"type":"function","title":"Parameters - Livekitex.Webhook.validate_webhook/3","doc":"- `body` - The raw webhook body (binary)\n- `auth_header` - The Authorization header value\n- `api_secret` - The API secret for signature validation","ref":"Livekitex.Webhook.html#validate_webhook/3-parameters"},{"type":"function","title":"Returns - Livekitex.Webhook.validate_webhook/3","doc":"- `{:ok, event}` - Successfully validated webhook with parsed event\n- `{:error, reason}` - Validation failed","ref":"Livekitex.Webhook.html#validate_webhook/3-returns"},{"type":"function","title":"Examples - Livekitex.Webhook.validate_webhook/3","doc":"iex> Livekitex.Webhook.validate_webhook(body, \"Bearer token\", \"secret\")\n    {:ok, %{event: \"room_started\", room: %{...}}}\n\n    iex> Livekitex.Webhook.validate_webhook(body, \"invalid\", \"secret\")\n    {:error, :invalid_signature}","ref":"Livekitex.Webhook.html#validate_webhook/3-examples"},{"type":"function","title":"Livekitex.Webhook.validate_webhook_conn/2","doc":"Validates a webhook using Plug.Conn for web frameworks.","ref":"Livekitex.Webhook.html#validate_webhook_conn/2"},{"type":"function","title":"Parameters - Livekitex.Webhook.validate_webhook_conn/2","doc":"- `conn` - Plug.Conn struct\n- `api_secret` - The API secret for signature validation","ref":"Livekitex.Webhook.html#validate_webhook_conn/2-parameters"},{"type":"function","title":"Returns - Livekitex.Webhook.validate_webhook_conn/2","doc":"- `{:ok, event}` - Successfully validated webhook with parsed event\n- `{:error, reason}` - Validation failed","ref":"Livekitex.Webhook.html#validate_webhook_conn/2-returns"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}